# -*- coding: iso-8859-1 -*-
"""
    MoinMoin - Vala Source Parser

    @copyright: 2009 Frederik
    @license: GNU GPL, see COPYING for details.

css:

pre.valaarea     { font-style: sans-serif; color: #000000; }

pre.valaarea span.ID       { color: #000000; }
pre.valaarea span.Char     { color: #004080; }
pre.valaarea span.Comment  { color: #808080; }
pre.valaarea span.Number   { color: #008080; font-weight: bold; }
pre.valaarea span.String   { color: #004080; }
pre.valaarea span.SPChar   { color: #0000C0; }
pre.valaarea span.ResWord  { color: #4040ff; font-weight: bold; }
pre.valaarea span.ConsWord { color: #008080; font-weight: bold; }
pre.valaarea span.ResWord2 { color: #0080ff; font-weight: bold; }
pre.valaarea span.Special  { color: #0000ff; }
pre.valaarea span.Preprc   { color: #804000; }

"""

from MoinMoin.parser._ParserBase import ParserBase

Dependencies = ['user'] # the "Toggle line numbers link" depends on user's language

class Parser(ParserBase):

    parsername = "ColorizedVala"
    extensions = ['.vala', '.vapi']
    Dependencies = Dependencies

    def setupRules(self):
        ParserBase.setupRules(self)

        self.addRulePair("Comment", r"/[*]", r"[*]/")
        self.addRule("Comment", r"//.*$")
        self.addRulePair("String", r'"""', r'"""')
        self.addRulePair("String", r'"', r'[^\\]"')
        self.addRule("Char", r"'\\.'|'[^\\]'")
        self.addRule("Number", r"[0-9](\.[0-9]*)?(eE[+-][0-9])?[flFLdD]?|0[xX][0-9a-fA-F]+[Ll]?")
        self.addRule("Preprc", r"^\s*#.*$")
        self.addRule("ID", r"[a-zA-Z_][0-9a-zA-Z_]*")
        self.addRule("SPChar", r"[~!%^&*()+=|\[\]:;,.<>/?{}-]")

        reserved_words = ['abstract', 'as', 'async', 'base', 'break', 'case',
        'catch', 'class', 'const', 'construct', 'continue', 'default',
        'delegate', 'delete', 'do', 'dynamic', 'else', 'ensures', 'enum',
        'errordomain', 'extern', 'finally', 'for', 'foreach', 'get', 'if', 'in',
        'inline', 'interface', 'internal', 'is', 'lock', 'new', 'out',
        'override', 'owned', 'private', 'protected', 'public', 'ref',
        'requires', 'return', 'set', 'signal', 'sizeof', 'static', 'struct',
        'switch', 'this', 'throw', 'throws', 'try', 'typeof', 'unowned',
        'value', 'var', 'virtual', 'void', 'volatile', 'weak', 'while',
        'yield']

        self.addReserved(reserved_words)

        reserved_words2 = ['namespace', 'using']

        special_words = ['bool', 'char', 'double', 'float', 'int', 'int8',
        'int16', 'int32', 'int64', 'long', 'short', 'size_t', 'ssize_t',
        'string', 'uchar', 'uint', 'uint16', 'uint32', 'uint64', 'ulong',
        'unichar', 'ushort']

        constant_words = ['true', 'false', 'null']

        self.addConstant(constant_words)

        self.addWords(reserved_words2, 'ResWord2')
        self.addWords(special_words, 'Special')

